==> minsol-0.0.1.tar.gz: minsol-0.0.1/minsol/__init__.py <==
import sys
import signal
import uuid
import yaml
from collections import Mapping
from optparse import OptionParser
import tornado.process


class Object(object):
    """
    Classes that inherit from this, work on the principle that each class 
    constructor is called once.

    When the object is initialized, all parameters are passed to their names.
    ::
        
        import minsol
        
        
        class Child(minsol.Object):
            def init(arg1, arg2=None, **other):
                self.arg1 = arg1
                self.arg2 = arg2


        ff = Child(arg1="val1", arg2="val2")

    """

    def __init__(self, **kwargs):
        if hasattr(self, "__initialized__"):
            return

        self.__initialized__ = True

        _mro = list(self.__class__.__mro__)
        _mro.reverse()

        for _class in _mro:
            if _class == Object \
            or not issubclass(_class, Object):
                continue

            try:
                _class.init(self, **kwargs)

            except Exception as error:
                sys.stderr.write("Error init class %s\n" % str(_class))
                sys.stderr.flush()

                raise error

    def init(self, **other):
        pass


class UUID(uuid.UUID):
    """
    ``jsonpickle`` lib can't serialize ``uuid.UUID``, 
    because ``__setattr__`` raise ``TypeError``
    
    In this class ``__setattr__`` works normaly.
    """
    def __setattr__(self, name, value):
        object.__setattr__(self, name, value)

    @staticmethod
    def gen4():
        """
        :return: generated ``minsol.UUID``
        """
        _uuid = uuid.uuid4()
        return UUID(int=_uuid.int)


class AsyncLoader(Object):
    def init(self, **kwargs):
        self.tasks = []

    def on_load(self):
        self.counter -= 1

        if not self.counter:
            self.callback()

    def load(self, callback):
        if not self.tasks:
            callback()
            return

        self.callback = callback
        self.counter = len(self.tasks)

        for task in self.tasks:
            task(self.on_load)


class Service(Object):
    """
    :ivar config: parsed ``yaml`` config file, ``dict``
    """

    #: Required command line arguments
    required_options = ["config"]

    def init(self, **kwargs):
        signal.signal(signal.SIGINT, self._on_sigint)
        signal.signal(signal.SIGTERM, self._on_sigterm)

        self.option_parser = OptionParser()

        self.config = {}

    def _on_sigint(self, signum, frame):
        self.stop()

    def _on_sigterm(self, signum, frame):
        self.stop()

    def init_option_parser(self):
        """
        Example::

            def init_option_parser(self):
                # rewrite standard option parser, if needed
                self.option_parser = OptionParser(...)

                # init standards
                minsol.Service.init_option_parser(self)

                self.option_parser.add_option...

        """
        self.option_parser.add_option(
            "--pidfile", type="string", dest="pidfile",
            help="Path to pidfile")

        self.option_parser.add_option(
            "--config", type="string", dest="config",
            help="Path to YAML config file")

    def init_config(self):
        """
        Config defaults. Example::

            def init_config(self):
                minsol.Service.init_config(self)

                self.config.update(dict(
                    host="localhost",
                    port=1234
                ))

        """
        pass

    def parse_options(self):
        self.option_kwargs, self.option_args = self.option_parser.parse_args()

        for r_option in self.required_options:
            if r_option not in self.option_kwargs.__dict__:
                raise Error("Option '%s' required" % r_option)

    def run(self):
        """
        The entry point to start the service.
        """

        self.init_config()
        self.init_option_parser()

        self.parse_options()

        config_path = self.option_kwargs.config
        if config_path:
            config_file = open(config_path, "r")
            config = yaml.load(config_file)
            config_file.close()

            self.config.update(config)

    def stop(self):
        """
        The entry point to stop the service.
        """
        pass


class MultiProcService(Service):
    def init_config(self):
        Service.init_config(self)

        self.config.update({
            "num_processes":-1
        })

    def fork(self):
        tornado.process.fork_processes(self.config["num_processes"])


class Error(Exception):
    def __init__(self, message):
        Exception.__init__(self)

        self.message = message

    def __str__(self):
        return self.get_message()

    def __repr__(self):
        return self.get_message()

    def get_message(self):
        return self.message

==> minsol-0.1.tar.gz: minsol-0.1/minsol/__init__.py <==
import sys
import signal
import uuid
import yaml
import importlib
import logging
import tornado.process
from collections import Mapping
from optparse import OptionParser


class Object(object):
    """
    Classes that inherit from this, work on the principle that each class 
    constructor is called once.

    When the object is initialized, all parameters are passed to their names.
    ::
        
        import minsol
        
        
        class Child(minsol.Object):
            def init(arg1, arg2=None, **other):
                self.arg1 = arg1
                self.arg2 = arg2


        ff = Child(arg1="val1", arg2="val2")

    """

    def __init__(self, **kwargs):
        if hasattr(self, "__initialized__"):
            return

        self.__initialized__ = True

        _mro = list(self.__class__.__mro__)
        _mro.reverse()

        for _class in _mro:
            if _class == Object \
            or not issubclass(_class, Object):
                continue

            try:
                _class.init(self, **kwargs)

            except Exception as error:
                sys.stderr.write("Error init class %s\n" % str(_class))
                sys.stderr.flush()

                raise error

    def init(self, **other):
        pass


class UUID(uuid.UUID):
    """
    ``jsonpickle`` lib can't serialize ``uuid.UUID``, 
    because ``__setattr__`` raise ``TypeError``
    
    In this class ``__setattr__`` works normaly.
    """
    def __setattr__(self, name, value):
        object.__setattr__(self, name, value)

    @staticmethod
    def gen4():
        """
        :return: generated ``minsol.UUID``
        """
        _uuid = uuid.uuid4()
        return UUID(int=_uuid.int)


class AsyncLoader(Object):
    def init(self, **kwargs):
        self.tasks = []

    def on_load(self):
        self.counter -= 1

        if not self.counter:
            self.callback()

    def load(self, callback):
        if not self.tasks:
            callback()
            return

        self.callback = callback
        self.counter = len(self.tasks)

        for task in self.tasks:
            task(self.on_load)


class Service(Object):
    """
    :ivar config: parsed ``yaml`` config file, ``dict``
    """

    #: Required command line arguments
    required_options = ["config"]

    def init(self, **kwargs):
        signal.signal(signal.SIGINT, self._on_sigint)
        signal.signal(signal.SIGTERM, self._on_sigterm)

        self.option_parser = OptionParser()

        self.config = {}

    def _on_sigint(self, signum, frame):
        self.stop()

    def _on_sigterm(self, signum, frame):
        self.stop()

    def init_option_parser(self):
        """
        Example::

            def init_option_parser(self):
                # rewrite standard option parser, if needed
                self.option_parser = OptionParser(...)

                # init standards
                minsol.Service.init_option_parser(self)

                self.option_parser.add_option...

        """
        self.option_parser.add_option(
            "--pidfile", type="string", dest="pidfile",
            help="Path to pidfile")

        self.option_parser.add_option(
            "--config", type="string", dest="config",
            help="Path to YAML config file")

    def init_config(self):
        """
        Config defaults. Example::

            def init_config(self):
                minsol.Service.init_config(self)

                self.config.update(dict(
                    host="localhost",
                    port=1234
                ))

        """
        pass

    def parse_options(self):
        self.option_kwargs, self.option_args = self.option_parser.parse_args()

        for r_option in self.required_options:
            if r_option not in self.option_kwargs.__dict__:
                raise Error("Option '%s' required" % r_option)

    def run(self):
        """
        The entry point to start the service.
        """

        self.init_config()
        self.init_option_parser()

        self.parse_options()

        config_path = self.option_kwargs.config
        if config_path:
            config_file = open(config_path, "r")
            config = yaml.load(config_file)
            config_file.close()

            self.config.update(config)

        logging.root.setLevel(logging.INFO)

        if "logfile" in self.config.keys():
            handler = logging.handlers.RotatingFileHandler(
                self.config["logfile"])

            logging.root.addHandler(handler)

    def stop(self):
        """
        The entry point to stop the service.
        """
        pass


class MultiProcService(Service):
    def init_config(self):
        Service.init_config(self)

        self.config.update({
            "num_processes":-1
        })

    def fork(self):
        tornado.process.fork_processes(self.config["num_processes"])


class Error(Exception):
    def __init__(self, message):
        Exception.__init__(self)

        self.message = message

    def __str__(self):
        return self.get_message()

    def __repr__(self):
        return self.get_message()

    def get_message(self):
        return self.message


def class_name_to_class(class_name):
    """
    convert ``'someproject.somens.Foor'`` to ``someproject.somens.Foor``
    """
    _class = class_name.split(".")

    class_module = ".".join(_class[:-1])
    class_module = importlib.import_module(class_module)

    _class = getattr(class_module, _class[-1])

    return _class


def class_names_to_classes(class_names):
    """
    convert
    
    ::
        [
            'someproject.somens.Foor',
            'otherproject.somens.Bar'
        ]
    
    to
    
    ::
        [
            someproject.somens.Foor,
            otherproject.somens.Bar
        ]
    
    """
    classes = []
    for class_name in class_names:
        _class = class_name_to_class(class_name)
        classes.append(_class)

    return classes
